/*
 * Copyright (c) 2000 - 2017 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#ifndef __BADGE_IPC_H__
#define __BADGE_IPC_H__

#include <badge.h>
#include <badge_setting.h>
#include <sys/types.h>
#include <glib.h>

#define BADGE_ADDR "/tmp/.badge.service"

#ifdef __cplusplus
extern "C" {
#endif

struct packet;

int badge_ipc_monitor_init(uid_t uid);
int badge_ipc_monitor_fini(void);

int badge_ipc_request_insert(const char *pkgname, const char *writable_pkg, const char *caller, uid_t uid);
int badge_ipc_request_delete(const char *pkgname, const char *caller, uid_t uid);
int badge_ipc_request_set_count(const char *pkgname, const char *caller, int count, uid_t uid);
int badge_ipc_request_get_count(const char *pkgname, unsigned int *count, uid_t uid);
int badge_ipc_request_set_display(const char *pkgname, const char *caller, unsigned int display_option, uid_t uid);
int badge_ipc_request_get_display(const char *pkgname, unsigned int *is_display, uid_t uid);

int badge_ipc_is_master_ready(void);
int badge_ipc_add_deferred_task(void (*badge_add_deferred_task)(void *data), void *user_data);
int badge_ipc_del_deferred_task(void (*badge_add_deferred_task)(void *data));

int badge_ipc_request_get_list(badge_foreach_cb callback, void *data, uid_t uid);
int badge_ipc_request_is_existing(const char *pkgname, bool *existing, uid_t uid);

int badge_ipc_request_update_setting(badge_setting_h setting, uid_t uid);
int badge_ipc_request_get_setting_by_appid(badge_setting_h *setting, const char *appid, uid_t uid);
int badge_ipc_init_badge(uid_t uid);

GVariant *badge_ipc_make_gvariant_from_setting(badge_setting_h setting);
int badge_ipc_make_setting_from_gvariant(badge_setting_h setting, GVariant *variant);

#ifdef __cplusplus
}
#endif
#endif
